.. advertools documentation master file, created by
   sphinx-quickstart on Fri Jul  6 20:35:47 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. meta::
   :google-site-verification: GcN6XL_hWV3BP2Y9FNLjmTXxysS7QxJs804KoF15n_c

.. meta::
    :description lang=en:
        Get productive as an online marketer with a Python package that helps
        in automating many of the important tasks.

advertools
==========
Online marketing productivity and analysis tools
------------------------------------------------

Generate keywords for SEM campaigns, create text ads on a large scale, analyze
multiple SERPs at once, gain insights from large social media posts, and get
productive as an online marketer.

If these are things you are interested in, then this package might make your
life a little easier.

.. toctree::
   :maxdepth: 2
   :titlesonly:

   About advertools <readme>
   Generate SEM Keywords <advertools.kw_generate>
   Create Text Ads on a Large Scale <advertools.ad_create>
   Create Text Ads From Description Text <advertools.ad_from_string>
   Emoji Tools <advertools.emoji>
   Extract Structured Entities from Text <advertools.extract>
   XML Sitemaps <advertools.sitemaps>
   Stop Words <advertools.stopwords>
   Text Analysis (absolute & weighted word frequency) <advertools.word_frequency>
   Word Tokenization (N-grams) <advertools.word_tokenize>
   Analyze Search Engine Results (SERPs) <advertools.serp>
   SEO Spider / Crawler <advertools.spider>
   Twitter Data <advertools.twitter>
   YouTube Data <advertools.youtube>

   Index & Change Log <include_changelog>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
